@@ -3,23 +3,19 @@ import sys
 import torch
 from copy import deepcopy
 from torch import nn
-try:
-    from tensorboardX import SummaryWriter
-
-    tensorboardX_flag = True
-except:
-    tensorboardX_flag = False
 
 try:
     import fitlog
 except:
     pass
+
+from torch.utils.data import Dataset
 from fantasybert.core.utils import ExplicitEnum
 from fantasybert.core.trainer_utils import PGD, FGM
 from fantasybert.core.trainer_utils import _save_model, _model_contains_inner_module
 from fantasybert.core.logger_utils import logger
 from fantasybert.core.optimization import ExponentialMovingAverage
-
+from fantasybert.core.tester import Tester
 
 class Callback(object):
     r"""
@@ -329,7 +325,7 @@ class CallbackManager(Callback):
                 total_callbacks.append(LRSchedulerCallback(self.trainer.scheduler))
 
             if callbacks == 'default':
-                total_callbacks.extend([EarlyStopCallback(self.args.patience)])  # , TensorboardCallback , FitlogCallback()
+                total_callbacks.extend([EarlyStopCallback(self.args.patience), FitlogCallback(self.args)])  # , TensorboardCallback ,
             else:
                 raise TypeError(
                 'can only support default and save_model, to use more callback, please pass in Callback module')
@@ -521,7 +517,7 @@ class FitlogCallback(Callback):
     fitlog中记录的关于这些数据集的结果就是来自第三个epoch的结果。
     """
 
-    def __init__(self, data=None, tester=None, log_loss_every=0, verbose=1, log_exception=False):
+    def __init__(self, args, data=None, tester=None, log_loss_every=0, verbose=1, log_exception=False):
         r"""
 
         :param ~fastNLP.DataSet,Dict[~fastNLP.DataSet] data: 传入DataSet对象，会使用多个Trainer中的metric对数据进行验证。如果需要
@@ -536,6 +532,9 @@ class FitlogCallback(Callback):
         self.datasets = {}
         self.testers = {}
         self._log_exception = log_exception
+
+        fitlog.set_log_dir(args.save_path)
+
         assert isinstance(log_loss_every, int) and log_loss_every >= 0
         if tester is not None:
             if isinstance(tester, dict):
@@ -550,10 +549,10 @@ class FitlogCallback(Callback):
 
         if isinstance(data, dict):
             for key, value in data.items():
-                assert isinstance(value, DataSet), f"Only DataSet object is allowed, not {type(value)}."
+                assert isinstance(value, Dataset), f"Only Dataset object is allowed when using fitlog Callback, not {type(value)}."
             for key, value in data.items():
                 self.datasets['data-' + key] = value
-        elif isinstance(data, DataSet):
+        elif isinstance(data, Dataset):
             self.datasets['data-test'] = data
         elif data is not None:
             raise TypeError("data receives dict[DataSet] or DataSet object.")
@@ -581,8 +580,8 @@ class FitlogCallback(Callback):
         if self._log_loss_every > 0:
             self._avg_loss += loss.item()
             if self.step % self._log_loss_every == 0:
-                fitlog.add_loss(self._avg_loss / self._log_loss_every * self.update_every, name='loss', step=self.step,
-                                epoch=self.epoch)
+                fitlog.add_loss(self._avg_loss / self._log_loss_every * self.args.gradient_accumulation_steps
+                                , name='loss', step=self.step, epoch=self.epoch)
                 self._avg_loss = 0
 
     def on_valid_end(self, eval_result, metric_key, optimizer, better_result):
@@ -781,80 +780,6 @@ class LRFinderCallback(Callback):
             self.pbar.write("Model reset. \nFind best lr={}".format(self.best_lr))
 
 
-class TensorboardCallback(Callback):
-    r"""
-    接受以下一个或多个字符串作为参数：
-    - "model"
-    - "loss"
-    - "metric"
-
-    .. warning::
-        fastNLP 已停止对此功能的维护，请等待 fastNLP 兼容 PyTorch1.1 的下一个版本。
-        或者使用和 fastNLP 高度配合的 fitlog（参见 :doc:`/tutorials/extend_3_fitlog` ）。
-
-    """
-
-    def __init__(self, *options):
-        super(TensorboardCallback, self).__init__()
-        args = {"model", "loss", "metric"}
-        for opt in options:
-            if opt not in args:
-                raise ValueError("Unrecognized argument {}. Expect one of {}".format(opt, args))
-        self.options = options
-        self._summary_writer = None
-        self.graph_added = False
-
-    def on_train_begin(self):
-        save_dir = self.trainer.save_path
-        if save_dir is None:
-            path = os.path.join("./", 'tensorboard_logs_{}'.format(self.trainer.start_time))
-        else:
-            path = os.path.join(save_dir, 'tensorboard_logs_{}'.format(self.trainer.start_time))
-        if tensorboardX_flag:
-            self._summary_writer = SummaryWriter(path)
-        else:
-            self._summary_writer = None
-
-    def on_batch_begin(self, batch_x, batch_y):
-        if "model" in self.options and self.graph_added is False:
-            # tesorboardX 这里有大bug，暂时没法画模型图
-            # from fastNLP.core.utils import _build_args
-            # inputs = _build_args(self.trainer.model, **batch_x)
-            # args = tuple([value for value in inputs.values()])
-            # args = args[0] if len(args) == 1 else args
-            # self._summary_writer.add_graph(self.trainer.model, torch.zeros(32, 2))
-            self.graph_added = True
-
-    def on_backward_begin(self, loss):
-        if "loss" in self.options and self._summary_writer:
-            self._summary_writer.add_scalar("loss", loss.item(), global_step=self.trainer.step)
-
-        if "model" in self.options and self._summary_writer:
-            for name, param in self.trainer.model.named_parameters():
-                if param.requires_grad:
-                    self._summary_writer.add_scalar(name + "_mean", param.mean(), global_step=self.trainer.step)
-                    # self._summary_writer.add_scalar(name + "_std", param.std(), global_step=self.trainer.step)
-                    self._summary_writer.add_scalar(name + "_grad_mean", param.grad.mean(),
-                                                    global_step=self.trainer.step)
-
-    def on_valid_end(self, eval_result, metric_key, optimizer, is_better_eval):
-        if "metric" in self.options and self._summary_writer:
-            for name, metric in eval_result.items():
-                for metric_key, metric_val in metric.items():
-                    self._summary_writer.add_scalar("valid_{}_{}".format(name, metric_key), metric_val,
-                                                    global_step=self.trainer.step)
-
-    def on_train_end(self):
-        if self._summary_writer:
-            self._summary_writer.close()
-            del self._summary_writer
-
-    def on_exception(self, exception):
-        if hasattr(self, "_summary_writer"):
-            self._summary_writer.close()
-            del self._summary_writer
-
-
 class CheckPointCallback(Callback):
     def __init__(self, save_path, delete_when_train_finish=True, recovery_fitlog=True):
         r"""
