@@ -2,8 +2,10 @@ import inspect
 import torch
 import warnings
 import numpy as np
+import torch.nn.functional as F
 from abc import abstractmethod
 from collections import defaultdict
+from fantasybert.core.utils import compute_corrcoef
 from fantasybert.core.trainer_utils import _build_args, _get_func_signature
 from fantasybert.core.utils import seq_len_to_mask
 
@@ -229,9 +231,6 @@ class ClassifyFPreRecMetric(MetricBase):
         :param float beta: f_beta分数， :math:`f_{beta} = \frac{(1 + {beta}^{2})*(pre*rec)}{({beta}^{2}*pre + rec)}` . 常用为 `beta=0.5, 1, 2` 若为0.5则精确率的权重高于召回率；若为1，则两者平等；若为2，则召回率权重高于精确率。
         """
 
-        if tag_vocab:
-            if not isinstance(tag_vocab, Vocabulary):
-                raise TypeError("tag_vocab can only be fastNLP.Vocabulary, not {}.".format(type(tag_vocab)))
         if f_type not in ('micro', 'macro'):
             raise ValueError("f_type only supports `micro` or `macro`', got {}.".format(f_type))
 
@@ -750,6 +749,32 @@ def _compute_f_pre_rec(beta_square, tp, fn, fp):
     return f, pre, rec
 
 
+class SpearmanMetric(MetricBase):
+    def __init__(self, pred=None, target=None, seq_len=None):
+        super().__init__()
+        self._init_param_map(pred=pred, target=target, seq_len=seq_len)
+
+        self.spearman = 0
+        self.batch_num = 0
+
+    def evaluate(self, pred, target, seq_len=None):
+        if not isinstance(pred[0], torch.Tensor):
+            raise TypeError(f"value in `pred` in must be torch.Tensor, got {type(pred[0])}.")
+
+        vec_a, vec_b = pred[:2]
+        sims = F.cosine_similarity(vec_a, vec_b).cpu().numpy()
+        labels = target.cpu().numpy()
+        spearman_correlation = compute_corrcoef(sims, labels)
+        self.spearman += spearman_correlation
+        self.batch_num += 1
+
+    def get_metric(self, reset=True):
+        evaluate_result = {'spearman_correlation': round(float(self.spearman) / (self.batch_num + 1e-12), 6)}
+        if reset:
+            self.spearman = 0
+            self.batch_num = 0
+        return evaluate_result
+
 
 def _prepare_metrics(metrics):
     r"""
@@ -779,10 +804,13 @@ def _prepare_metrics(metrics):
                         metric = AccuracyMetric()
                     elif metric == 'fpr':
                         metric = ClassifyFPreRecMetric()
+                    elif metrics == 'spearman':
+                        _metrics = SpearmanMetric()
                     elif metric == 'spanfpr':
                         metric = SpanFPreRecMetric()  # 要传入vocab
                     else:
-                        raise TypeError(f'expected to be str among acc, fpr and spanfpr, got str {metrics}')
+                        raise TypeError(f'expected to be str among acc, fpr, spearman_correlation and spanfpr,'
+                                        f' got str {metrics}')
                     _metrics.append(metric)
 
                 else:
@@ -793,6 +821,8 @@ def _prepare_metrics(metrics):
                 _metrics = AccuracyMetric()
             elif metrics == 'fpr':
                 _metrics = ClassifyFPreRecMetric()
+            elif metrics == 'spearman':
+                _metrics = SpearmanMetric()
             elif metrics == 'spanfpr':
                 _metrics = SpanFPreRecMetric()
             else:
@@ -803,4 +833,5 @@ def _prepare_metrics(metrics):
         else:
             raise TypeError(f"The type of metrics should be `list[fastNLP.MetricBase]` or `fastNLP.MetricBase`, "
                             f"got {type(metrics)}.")
-    return _metrics
\ No newline at end of file
+    return _metrics
+
