@@ -13,8 +13,8 @@ from torch.cuda.amp import autocast as autocast, GradScaler
 from fantasybert.models.modeling_utils import build_bert_optim_parameters
 from fantasybert.core.tester import Tester
 from fantasybert.core.trainer_utils import _build_args, _get_func_signature, _model_contains_inner_module, _save_model
-from fantasybert.core.utils import TrainerState, _move_dict_value_to_device
-from fantasybert.core.data_utils import BatchIter
+from fantasybert.core.utils import _move_dict_value_to_device
+from fantasybert.core.data_utils import BatchIter, TrainerState
 from fantasybert.core.callback import CallbackManager, Callback, CallbackException
 from fantasybert.core.logger_utils import logger
 from fantasybert.core.loss_main import prepare_losser, LossBase
@@ -31,6 +31,7 @@ class Trainer(object):
                  train_data: Union[Dataset, BatchIter, DataLoader],
                  tester: Optional[Tester] = None,
                  loss: Union[LossBase, str] = 'cross_entropy',
+                 eval_loss: Union[LossBase, str] = 'as_train',
                  optimizer: Union[Optimizer, str] = 'AdamW',
                  scheduler: Union[LambdaLR, str] = None,
                  dev_data: Union[Dataset, BatchIter, DataLoader] = None,
@@ -38,6 +39,7 @@ class Trainer(object):
                  callbacks: Union[List[Callback], List[str], Callback, str] = 'default',
                  stay_default_callback: bool = False, # set stay_default_callback = True only when we pass new callbacks, therefore callbacks!='default'
                  metrics: Union[List[MetricBase], List[str], MetricBase, str] = None,
+                 collate_fn=None,
                  train_collate_fn=None,
                  eval_collate_fn=None,
                  train_shuffle: bool = True,
@@ -51,8 +53,12 @@ class Trainer(object):
         super(Trainer, self).__init__()
 
         self.args = args
-        self.train_collate_fn = train_collate_fn
-        self.eval_collate_fn = eval_collate_fn
+        if collate_fn is not None and train_collate_fn is None and eval_collate_fn is None:
+            self.train_collate_fn = collate_fn
+            self.eval_collate_fn = collate_fn
+        else:
+            self.train_collate_fn = train_collate_fn
+            self.eval_collate_fn = eval_collate_fn
         self.train_shuffle = train_shuffle
         self.eval_shuffle = eval_shuffle
 
@@ -66,6 +72,7 @@ class Trainer(object):
 
         self.train_data = train_data
         self.dev_data = dev_data
+        self.test_data = test_data
         self.use_tqdm = use_tqdm
         self.stay_default_callback = stay_default_callback
 
@@ -94,7 +101,7 @@ class Trainer(object):
         if isinstance(train_data, Dataset):
             self.data_iterator = BatchIter(dataset=train_data, batch_size=self.batch_size, sampler=self.args.sampler,
                                              num_workers=self.args.num_workers, drop_last=self.args.drop_last,
-                                            collate_fn=train_collate_fn, shuffle=self.train_shuffle,
+                                            collate_fn=self.train_collate_fn, shuffle=self.train_shuffle,
                                                 use_block_shuffle=self.use_block_shuffle,**kwargs)
         elif isinstance(train_data, DataLoader):
             self.data_iterator = train_data
@@ -136,6 +143,10 @@ class Trainer(object):
 
         # loss
         self.losser = prepare_losser(loss)
+        if eval_loss == 'as_train':
+            self.eval_loss = loss
+        else:
+            self.eval_loss = eval_loss
 
         # metrics
         self.metrics = _prepare_metrics(metrics)
@@ -153,6 +164,7 @@ class Trainer(object):
             if tester is None:
                 self.tester = Tester(model=self.model,
                                  args=self.args,
+                                 loss=self.eval_loss,
                                  data=self.dev_data,
                                  metrics=self.metrics,
                                  collate_fn=self.eval_collate_fn,
@@ -187,7 +199,7 @@ class Trainer(object):
         try:
             self.model.train()
             self._load_best_model = load_best_model
-            self.start_time = str(datetime.datetime.now().strftime('%Y-%m-%d-%H-%M-%S-%f'))
+            self.start_time = str(datetime.datetime.now().strftime('%Y-%m-%d-%H-%M-%S'))
             start_time = time.time()
             logger.info("training epochs started " + self.start_time)
             self.step = 0
@@ -252,8 +264,10 @@ class Trainer(object):
                 for batch in self.data_iterator:
                     self.step += 1
                     batch_x, batch_y = self._get_batch_xy(batch)
-
-                    _move_dict_value_to_device(batch_x, batch_y, device=self.device)
+                    if batch_y is not None:
+                        _move_dict_value_to_device(batch_x, batch_y, device=self.device)
+                    else:
+                        _move_dict_value_to_device(batch_x, device=self.device)
                     _move_dict_value_to_device(batch, device=self.device)
 
                     # negative sampling; replace unknown; re-weight batch_y
@@ -398,7 +412,7 @@ class Trainer(object):
             logger.info("Failed to load best model.")
         tester = Tester(model=self.model,
                args=self.args,
-               data=self.dev_data,
+               data=self.test_data,
                metrics=self.metrics,
                collate_fn=self.eval_collate_fn,
                shuffle=self.eval_shuffle,
