@@ -1,5 +1,4 @@
 #! -*- coding: utf-8 -*-
-# 代码合集
 
 import os, sys, six, re, json
 from collections import OrderedDict, UserDict
@@ -8,9 +7,7 @@ import inspect
 import torch
 import time
 import functools
-from typing import Any, Optional, List, Tuple, Union, Dict
 import torch.nn.functional as F
-import dataclasses
 import json
 import os
 import torch.nn as nn
@@ -22,7 +19,6 @@ import torch
 from dataclasses import dataclass, field, asdict
 import inspect
 from fantasybert.core.logger_utils import logger
-from fantasybert.tokenization.tokenizers import BertTokenizer
 _open_ = open
 is_py2 = six.PY2
 
@@ -30,116 +26,6 @@ if not is_py2:
     basestring = str
 
 
-def set_seed(args):
-    SEED = args.SEED
-    torch.manual_seed(SEED)
-    torch.cuda.manual_seed_all(SEED)
-    torch.backends.cudnn.deterministic = True
-    torch.backends.cudnn.benchmark = True
-
-def set_block_shuffle_args(batch_in_shuffle, sort_bs_num=None, sort_key=lambda x: len(x[0])):
-    return {'batch_in_shuffle':batch_in_shuffle,
-            'sort_bs_num': sort_bs_num,
-            'sort_key':sort_key}
-
-
-
-@dataclass
-class TrainerState:
-    # must passed in parameters
-    learning_rate: float = field(default_factory=float)
-    n_epochs: int = field(default_factory=int)
-    max_len: int = field(default_factory=int)
-    batch_size: int = field(default_factory=int)
-    save_path: str = field(default_factory=str)
-    model_path: str = field(default_factory=str)
-    data_dir: str = field(default_factory=str)
-    tokenizer: BertTokenizer = None
-
-
-    train_batch_size: int = None
-    eval_batch_size: int = None
-    SEED: int = 42
-    metric_key: Optional[str] = "accuracy"
-    patience: int = 5
-
-    global_step: int = 0
-    max_steps: int = 0
-    test_use_tqdm = False
-
-    save_only_param: bool = True
-
-    # block_shuffle_args: Dict[bool, int, Any] = field(default_factory=set_block_shuffle_args)
-    use_block_shuffle: bool = False
-    eval_use_block_shuffle: bool = False
-    batch_in_shuffle: bool = True
-    sort_bs_num: int = None
-    sort_key = None
-
-    num_labels: int = None
-    add_polynominal: bool = False
-
-    save_step_model: bool = False
-
-    best_metric: Optional[float] = None
-
-    fp16: bool = False
-    use_adv: Union[bool, str] = False
-    use_ema: bool = False
-    use_lookahead: bool = False
-
-    gradient_clip: bool = True
-    clip_value = 1.0
-    clip_type: str = 'norm'
-
-    gradient_accumulation_steps: int = 1
-
-    warmup_ratios: float = 0.1
-    weight_decay: float = 1e-3
-
-    load_checkpoint: bool = False
-
-    # dataloader
-    num_workers = 0
-    sampler = None
-    drop_last: bool = False
-    train_shuffle: bool = True
-    eval_shuffle: bool = False
-    pin_memory = None
-
-
-    device: Union[torch.device, str] = torch.device("cuda" if torch.cuda.is_available() else "cpu")
-
-    def __getstate__(self):
-        return self.__dict__
-
-    def __post_init__(self):
-        if isinstance(self.device, str):
-            self.device = torch.device(self.device)
-
-        self.sort_key = lambda x: len(self.tokenizer.tokenize(x[0]))  # x[0] is text in Dataset
-
-        os.makedirs(self.save_path, exist_ok=True)
-
-        if self.batch_size is not None and self.train_batch_size is None and self.eval_batch_size is None:
-            self.train_batch_size = self.eval_batch_size = self.batch_size
-
-    def save_to_json(self, json_path: str):
-        json_string = json.dumps(dataclasses.asdict(self), indent=2, sort_keys=True) + "\n"
-        with open(json_path, "w", encoding="utf-8") as f:
-            f.write(json_string)
-
-    @classmethod
-    def load_from_json(cls, json_path: str):
-        with open(json_path, "r", encoding="utf-8") as f:
-            text = f.read()
-        return cls(**json.loads(text))
-
-    @property
-    def to_dict(self):
-        return asdict(self)
-
-
 @dataclass
 class Const:
     INPUT = 'words'
@@ -627,7 +513,7 @@ def _move_dict_value_to_device(*args, device: torch.device, non_blocking=False):
                 if isinstance(value, torch.Tensor):
                     arg[key] = value.to(device, non_blocking=non_blocking)
         else:
-            raise TypeError("Only support `dict` type right now.")
+            raise TypeError(f"Only support `dict` type right now got type {type(arg)}")
 
 
 class ExplicitEnum(Enum):
